| Portability | non-portable (uses STM) |
|---|---|
| Stability | experimental |
| Maintainer | phil@haphazardhouse.net |
| Safe Haskell | None |
Network.Transport.TCP
Description
TCP transports deliver messages to other Endpoints using TCP/IP.
Each TCP transport manages both socket bindings and connections on behalf of
Endpoints, dynamically opening / closing new sockets as needed to deliver
messages to other Endpoints using TCP transports.
- newTCPTransport :: Resolver -> IO Transport
- newTCPTransport6 :: Resolver -> IO Transport
- lookupAddresses :: Family -> SocketType -> Address -> IO [SockAddr]
- lookupTCPAddress :: Address -> Family -> IO SockAddr
- lookupWildcardTCPAddress :: Address -> Family -> IO SockAddr
Documentation
newTCPTransport :: Resolver -> IO TransportSource
newTCPTransport6 :: Resolver -> IO TransportSource
lookupAddresses :: Family -> SocketType -> Address -> IO [SockAddr]Source
lookupTCPAddress :: Address -> Family -> IO SockAddrSource
lookupWildcardTCPAddress :: Address -> Family -> IO SockAddrSource